==> poligrain-0.0.1.tar.gz: poligrain-0.0.1/README.md <==
# poligrain

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

<!-- SPHINX-START -->

`poligrain` is a Python package developed within the COST Action OPENSENSE to
simplify common tasks for working with **po**int, **li**ne and **gr**idded
sensor data, focusing on **rain**fall observations.

This is currently an early draft of the package and no, or only preliminary
functionality, is there.

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/OpenSenseAction/poligrain/workflows/CI/badge.svg
[actions-link]:             https://github.com/OpenSenseAction/poligrain/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/poligrain
[conda-link]:               https://github.com/conda-forge/poligrain-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/OpenSenseAction/poligrain/discussions
[pypi-link]:                https://pypi.org/project/poligrain/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/poligrain
[pypi-version]:             https://img.shields.io/pypi/v/poligrain
[rtd-badge]:                https://readthedocs.org/projects/poligrain/badge/?version=latest
[rtd-link]:                 https://poligrain.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->

==> poligrain-0.0.2.tar.gz: poligrain-0.0.2/README.md <==
# poligrain

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

<!-- SPHINX-START -->

`poligrain` is a Python package developed within the COST Action OPENSENSE to
simplify common tasks for working with **po**int, **li**ne and **gr**idded
sensor data, focusing on **rain**fall observations.

This is currently an early draft of the package and no, or only preliminary
functionality, is there...

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/OpenSenseAction/poligrain/workflows/CI/badge.svg
[actions-link]:             https://github.com/OpenSenseAction/poligrain/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/poligrain
[conda-link]:               https://github.com/conda-forge/poligrain-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/OpenSenseAction/poligrain/discussions
[pypi-link]:                https://pypi.org/project/poligrain/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/poligrain
[pypi-version]:             https://img.shields.io/pypi/v/poligrain
[rtd-badge]:                https://readthedocs.org/projects/poligrain/badge/?version=latest
[rtd-link]:                 https://poligrain.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
